It is easy to use bert in triton now.
Algorithm Engineer only need to focus to write proprocess function to make his model work.

pls see examples

[code](https://codechina.csdn.net/yyw794/triton_bert)



